@@ -42,7 +42,7 @@ from AliceCli.utils.utils import reboot, systemLogs
 
 
 @click.command(name='installSoundDevice')
-@click.option('-d', '--device', type=click.Choice(['respeaker2', 'respeaker4', 'respeaker4MicLinearArray', 'respeaker6MicArray'], case_sensitive=False))
+@click.option('-d', '--device', type=click.Choice(['respeaker2Mics', 'respeaker4Mics', 'respeaker4MicLinearArray', 'respeaker6MicArray'], case_sensitive=False))
 @click.pass_context
 @checkConnection
 def installSoundDevice(ctx: click.Context, device: str):
@@ -56,7 +56,7 @@ def installSoundDevice(ctx: click.Context, device: str):
 	ctx.invoke(uninstallSoundDevice, device=device, return_to_main_menu=False)
 	commons.waitAnimation()
 	sshCmd('sudo apt-get install git -y')
-	if device.lower() in {'respeaker2', 'respeaker4', 'respeaker4miclineararray', 'respeaker6micarray'}:
+	if device.lower() in {'respeaker2Mics', 'respeaker4Mics', 'respeaker4miclineararray', 'respeaker6micarray'}:
 		sshCmd('git clone https://github.com/HinTak/seeed-voicecard.git ~/seeed-voicecard/')
 		sshCmd('git -C ~/seeed-voicecard/ checkout v5.9 && git -C ~/seeed-voicecard/ pull')
 		sshCmd('cd ~/seeed-voicecard/ && sudo ./install.sh')
@@ -67,7 +67,7 @@ def installSoundDevice(ctx: click.Context, device: str):
 
 
 @click.command(name='uninstallSoundDevice')
-@click.option('-d', '--device', type=click.Choice(['respeaker2', 'respeaker4', 'respeaker4MicLinearArray', 'respeaker6MicArray'], case_sensitive=False))
+@click.option('-d', '--device', type=click.Choice(['respeaker2Mics', 'respeaker4Mics', 'respeaker4MicLinearArray', 'respeaker6MicArray'], case_sensitive=False))
 @click.pass_context
 @checkConnection
 def uninstallSoundDevice(ctx: click.Context, device: str, return_to_main_menu: bool = True):  # NOSONAR
@@ -78,7 +78,7 @@ def uninstallSoundDevice(ctx: click.Context, device: str, return_to_main_menu: b
 		if not device:
 			return
 
-	if device.lower() in {'respeaker2', 'respeaker4', 'respeaker4miclineararray', 'respeaker6micarray'}:
+	if device.lower() in {'respeaker2Mics', 'respeaker4Mics', 'respeaker4miclineararray', 'respeaker6micarray'}:
 		result = sshCmdWithReturn('test -d ~/seeed-voicecard/ && echo "1"')[0].readline()
 		if result:
 			sshCmd('cd ~/seeed-voicecard/ && sudo ./uninstall.sh')
@@ -94,10 +94,10 @@ def getDeviceName() -> str:
 	return inquirer.select(
 		message='Select your device',
 		choices=[
-			Choice('respeaker2', name='Respeaker 2'),
-			Choice('respeaker4', name='Respeaker 4-mic array'),
-			Choice('respeaker4MicLinearArray', name='Respeaker 4 mic linear array'),
-			Choice('respeaker6MicArray', name='Respeaker 6 mic array')
+			Choice('respeaker2Mics', name='Respeaker 2 mics'),
+			Choice('respeaker4Mics', name='Respeaker 4 mics array'),
+			Choice('respeaker4MicLinearArray', name='Respeaker 4 mics linear array'),
+			Choice('respeaker6MicArray', name='Respeaker 6 mics array')
 		]
 	).execute()
 
@@ -162,6 +162,7 @@ def install(ctx: click.Context, force: bool, name: str):
 	elif name == 'ProjectAliceSatellite':
 		config = getAliceSatConfig(config, releaseType)
 	else:
+		config = dict()
 		commons.printError(f'Unknown install type {name}')
 
 	commons.waitAnimation()
@@ -222,7 +223,7 @@ def prepareSdCard(ctx: click.Context):  # NOSONAR
 	operatingSystem = platform.system().lower()
 
 	balenaExecutablePath = getBalenaPath()
-	flasherAvailable = balenaExecutablePath != None
+	flasherAvailable = balenaExecutablePath is not None
 
 	downloadsPath = Path.home() / 'Downloads'
 
@@ -431,6 +432,7 @@ def prepareSdCard(ctx: click.Context):  # NOSONAR
 		commons.returnToMainMenu(ctx, pause=True, message="I'm really sorry, but I just can't continue without this info, sorry for wasting your time...")
 
 	if len(drives) == 1:
+		# noinspection PyBroadException
 		try:
 			device = drives[0].value
 		except:
@@ -605,6 +607,8 @@ def getAliceConfig(confs, releaseType):
 	githubToken = ''
 	enableDataStoring = True
 	skillAutoUpdate = True
+	ttsGender = 'male'
+	ttsVoice = 'en-US'
 
 	if advancedConfigs:
 		asr = inquirer.select(
@@ -632,7 +636,7 @@ def getAliceConfig(confs, releaseType):
 				]
 		).execute()
 
-		ttsGender = 'male'
+		ttsVoiceChoiceText = 'Choose your TTS voice'
 		if tts == 'amazon':
 			awsAccessKey = inquirer.secret(
 					message='Enter your AWS access key',
@@ -647,7 +651,7 @@ def getAliceConfig(confs, releaseType):
 			).execute()
 
 			ttsVoice = inquirer.select(
-				message='Choose your TTS voice',
+				message=ttsVoiceChoiceText,
 				choices=commons.AMAZON_VOICES[activeLanguage] if activeLanguage in commons.AMAZON_VOICES and len(commons.AMAZON_VOICES[activeLanguage]) > 0 else ['en-US']
 			).execute()
 
@@ -655,30 +659,28 @@ def getAliceConfig(confs, releaseType):
 
 		elif tts == 'google':
 			ttsVoice = inquirer.select(
-				message='Choose your TTS voice',
+				message=ttsVoiceChoiceText,
 				choices=commons.GOOGLE_VOICES[activeLanguage] if activeLanguage in commons.GOOGLE_VOICES and len(commons.GOOGLE_VOICES[activeLanguage]) > 0 else ['en-US']
 			).execute()
 
 			ttsVoice, ttsGender = ttsVoice.split('/')
 		elif tts == 'watson':
 			ttsVoice = inquirer.select(
-				message='Choose your TTS voice',
+				message=ttsVoiceChoiceText,
 				choices=commons.WATSON_VOICES[activeLanguage] if activeLanguage in commons.WATSON_VOICES and len(commons.WATSON_VOICES[activeLanguage]) > 0 else ['en-US']
 			).execute()
 
 			ttsVoice, ttsGender = ttsVoice.split('/')
 		elif tts == 'mycroft':
 			ttsVoice = inquirer.select(
-				message='Choose your TTS voice',
+				message=ttsVoiceChoiceText,
 				choices=commons.MYCROFT_VOICES[activeLanguage] if activeLanguage in commons.MYCROFT_VOICES and len(commons.MYCROFT_VOICES[activeLanguage]) > 0 else ['en-US']
 			).execute()
 		elif tts == 'pico':
 			ttsVoice = inquirer.select(
-				message='Choose your TTS voice',
+				message=ttsVoiceChoiceText,
 				choices=commons.PICO_VOICES[activeLanguage] if activeLanguage in commons.PICO_VOICES and len(commons.PICO_VOICES[activeLanguage]) > 0 else ['en-US']
 			).execute()
-		else:
-			ttsVoice = 'en-US'
 
 		if tts == 'google' or asr == 'google':
 			googleServiceFile = inquirer.filepath(
@@ -693,7 +695,7 @@ def getAliceConfig(confs, releaseType):
 		).execute()
 
 		devMode = inquirer.confirm(
-				message='Do you want to activate the developer mode?',
+				message='Do you want to activate the developer mode? You will need a Github account!',
 				default=False
 		).execute()
 
@@ -792,13 +794,13 @@ def getAliceSatConfig(confs, releaseType):
 def inquireAudioDevice():
 	return inquirer.select(
 			message='Select your audio hardware if listed',
-			default='respeaker2',
+			default='respeaker2Mics',
 			choices=[
-				Choice('respeaker2', name='Respeaker 2 mics'),
-				Choice('respeaker4', name='Respeaker 4 mic array'),
-				Choice('respeaker4MicLinear', name='Respeaker 4 mic linear array'),
-				Choice('respeaker6', name='Respeaker 6 mic array'),
-				Choice('respeaker7', name='Respeaker 7'),
+				Choice('respeaker2Mics', name='Respeaker 2 mics'),
+				Choice('respeaker4Mics', name='Respeaker 4 mics array'),
+				Choice('respeaker4MicLinear', name='Respeaker 4 mics linear array'),
+				Choice('respeaker6', name='Respeaker 6 mics array'),
+				Choice('respeaker7MicArray', name='Respeaker 7 mics array'),
 				Choice('respeakerCoreV2', name='Respeaker Core version 2'),
 				Choice('googleAIY', name='Google AIY'),
 				Choice('googleAIY2', name='Google AIY 2'),
